@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use 5.004;
 
-$VERSION = "0.17002"; 
+$VERSION = "0.17003"; 
 
 use overload (
 	'""'	   =>	'stringify',
@@ -330,6 +330,7 @@ sub run_clauses ($$$\@) {
 			my $more = 0;
 			local($Error::THROWN);
 			my $ok = eval {
+			    local $@ = $err;
 			    if($wantarray) {
 				@{$result} = $code->($err,\$more);
 			    }
@@ -349,8 +350,8 @@ sub run_clauses ($$$\@) {
 			else {
 			    $err = defined($Error::THROWN)
 				    ? $Error::THROWN : $@;
-                $err = $Error::ObjectifyCallback->({'text' =>$err})
-                    unless ref($err);
+				$err = $Error::ObjectifyCallback->({'text' =>$err})
+					unless ref($err);
 			}
 			last CATCH;
 		    };
@@ -364,6 +365,7 @@ sub run_clauses ($$$\@) {
 	    my $code = $clauses->{'otherwise'};
 	    my $more = 0;
 	    my $ok = eval {
+		local $@ = $err;
 		if($wantarray) {
 		    @{$result} = $code->($err,\$more);
 		}
@@ -382,9 +384,9 @@ sub run_clauses ($$$\@) {
 	    else {
 		$err = defined($Error::THROWN)
 			? $Error::THROWN : $@;
-            
-        $err = $Error::ObjectifyCallback->({'text' =>$err}) 
-            unless ref($err);
+
+		$err = $Error::ObjectifyCallback->({'text' =>$err}) 
+			unless ref($err);
 	    }
 	}
     }
@@ -404,7 +406,7 @@ sub try (&;$) {
 
     do {
 	local $Error::THROWN = undef;
-    local $@ = undef;
+	local $@ = undef;
 
 	$ok = eval {
 	    if($wantarray) {
@@ -426,7 +428,7 @@ sub try (&;$) {
     shift @Error::STACK;
 
     $err = run_clauses($clauses,$err,wantarray,@result)
-	unless($ok);
+    unless($ok);
 
     $clauses->{'finally'}->()
 	if(defined($clauses->{'finally'}));
@@ -690,7 +692,7 @@ C<BLOCK> will be passed two arguments. The first will be the error
 being thrown. The second is a reference to a scalar variable. If this
 variable is set by the catch block then, on return from the catch
 block, try will continue processing as if the catch block was never
-found.
+found. The error will also be available in C<$@>.
 
 To propagate the error the catch block may call C<$err-E<gt>throw>
 
@@ -711,7 +713,7 @@ type.
 Catch any error by executing the code in C<BLOCK>
 
 When evaluated C<BLOCK> will be passed one argument, which will be the
-error being processed.
+error being processed. The error will also be available in C<$@>.
 
 Only one otherwise block may be specified per try block
 
